#!/usr/bin/env python
# -*- coding:utf-8 -*-
"""
@author: HJK
@file: __version__.py
@time: 2019-02-08
"""

__title__ = "x12306"
__description__ = "12306查票助手，一键查询沿途所有站点，在买不到票的时候，先上车后补票，暂不支持抢票"
__url__ = "https://github.com/0xHJK/x12306"
__version__ = "0.2.1"
__author__ = "HJK"
__author_email__ = "HJKdev@gmail.com"
__license__ = "MIT License"
__copyright__ = "Copyright 2024 HJK"
